@@ -10,13 +10,11 @@ class MyTaggable(Taggable, MixinBase):
 
 class TaggableTestCase(BaseTestCase):
     def test_instantiates(self):
-        """ Ensures the class instantiates without arguments
-        """
+        """Ensures the class instantiates without arguments"""
         Taggable()
 
     def test_instantiates_with_tags(self):
-        """ Ensures datafile inherits correctly from the Taggable class and passes arguments through
-        """
+        """Ensures datafile inherits correctly from the Taggable class and passes arguments through"""
         taggable = MyTaggable(tags="")
         self.assertEqual(len(taggable.tags), 0)
 
@@ -30,16 +28,14 @@ class TaggableTestCase(BaseTestCase):
             MyTaggable(tags=":a b c")
 
     def test_instantiates_with_tag_set(self):
-        """ Ensures datafile inherits correctly from the Taggable class and passes arguments through
-        """
+        """Ensures datafile inherits correctly from the Taggable class and passes arguments through"""
         taggable_1 = MyTaggable(tags="")
         self.assertIsInstance(taggable_1.tags, TagSet)
         taggable_2 = MyTaggable(tags=taggable_1.tags)
         self.assertFalse(taggable_1 is taggable_2)
 
     def test_fails_to_instantiates_with_non_iterable(self):
-        """ Ensures datafile inherits correctly from the Taggable class and passes arguments through
-        """
+        """Ensures datafile inherits correctly from the Taggable class and passes arguments through"""
 
         class NoIter:
             pass
@@ -52,15 +48,13 @@ class TaggableTestCase(BaseTestCase):
         )
 
     def test_reset_tags(self):
-        """ Ensures datafile inherits correctly from the Taggable class and passes arguments through
-        """
+        """Ensures datafile inherits correctly from the Taggable class and passes arguments through"""
         taggable = MyTaggable(tags="a b")
         taggable.tags = "b c"
         self.assertEqual(set(taggable.tags), {Tag("b"), Tag("c")})
 
     def test_valid_tags(self):
-        """ Ensures valid tags do not raise an error
-        """
+        """Ensures valid tags do not raise an error"""
         taggable = MyTaggable()
         taggable.add_tags("a-valid-tag")
         taggable.add_tags("a:tag")
@@ -83,8 +77,7 @@ class TaggableTestCase(BaseTestCase):
         )
 
     def test_invalid_tags(self):
-        """ Ensures invalid tags raise an error
-        """
+        """Ensures invalid tags raise an error"""
         taggable = MyTaggable()
 
         for tag in "-bah", "humbug:", "SHOUTY", r"back\slashy", {"not-a": "string"}:
@@ -92,8 +85,7 @@ class TaggableTestCase(BaseTestCase):
                 taggable.add_tags(tag)
 
     def test_mixture_valid_invalid(self):
-        """ Ensures that adding a variety of tags, some of which are invalid, doesn't partially add them to the object
-        """
+        """Ensures that adding a variety of tags, some of which are invalid, doesn't partially add them to the object"""
         taggable = MyTaggable()
         taggable.add_tags("first-valid-should-be-added")
         try:
